@@ -40,6 +40,30 @@
 #include "hpOutput.h"
 #include "syntFilter.h"
 
+#if (defined(WIN32)  ||  defined(_WIN32))  &&  !defined(_WIN64)
+__inline long int rint(double x)
+{
+    _asm 
+    {
+        fld x
+        frndint
+        fstp x
+    }
+    return (long int) x;
+}
+#elif defined (_WIN64)
+#include <intrin.h>
+__inline__ long int rint(double x)
+{
+#ifdef _M_X64
+    return (long int) _mm_cvtsd_si64x(_mm_loadu_pd ((const double *) &x));
+#else
+#warning "Not Supported: Replacing with a simple C cast."
+	return (long int) (x);
+#endif
+}
+#endif
+
 /*----------------------------------------------------------------*
  *  Initiation of decoder instance.
  *---------------------------------------------------------------*/
